<?php

namespace App\Rhawn\Services\Chemsite;

use App\Exceptions\ServerRunTimeException;
use App\Rhawn\Repositories\Contracts\Chemsite\ChemsiteCustomerRepository;

class ChemsiteCustomerService
{
    private ChemsiteCustomerRepository $customerRepository;

    public function __construct(ChemsiteCustomerRepository $chemsiteCustomerRepository)
    {
        $this->customerRepository = $chemsiteCustomerRepository;
    }

    public function getCustomerThroughCusCode($cusCode)
    {
        return $this->customerRepository->getRhawnCustomerThroughtCusCode($cusCode);
    }

    public function getCustomerListByCusCode($cusNo,$offset,$limit): ?array
    {
        return $this->customerRepository->getCustomerList(['cus_no' => $cusNo],$offset,$limit);
    }


    /**
     * 检查客户信息是否存在
     * @param $cusCode
     * @return mixed
     * @throws ServerRunTimeException
     */
    public function checkCustomerExist($cusCode)
    {
        //查询用户是否存在
        $customer = $this->customerRepository->getRhawnCustomerThroughtCusCode($cusCode);
        if(!$customer){
            throw new ServerRunTimeException('客户编号为:['.$cusCode.']的用户不存在!');
        }
        return $customer;
    }
}
